#[non_exhaustive]pub enum BigQuerySchemaModification {
SchemaModificationUnspecified,
SchemaNewColumns,
SchemaRemovedColumns,
UnknownValue(UnknownValue),
}Expand description
Attributes evaluated to determine if a schema has been modified. New values may be added at a later time.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SchemaModificationUnspecified
Unused
SchemaNewColumns
Profiles should be regenerated when new columns are added to the table. Default.
SchemaRemovedColumns
Profiles should be regenerated when columns are removed from the table.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using BigQuerySchemaModification::value or BigQuerySchemaModification::name.
Implementations