#[non_exhaustive]pub struct BigQueryKey {
pub table_reference: Option<BigQueryTable>,
pub row_number: i64,
/* private fields */
}Expand description
Row key for identifying a record in BigQuery table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_reference: Option<BigQueryTable>Complete BigQuery table reference.
row_number: i64Row number inferred at the time the table was scanned. This value is
nondeterministic, cannot be queried, and may be null for inspection
jobs. To locate findings within a table, specify
inspect_job.storage_config.big_query_options.identifying_fields in
CreateDlpJobRequest.
Implementations
Sourceimpl BigQueryKey
impl BigQueryKey
pub fn new() -> Self
Sourcepub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<BigQueryTable>,
pub fn set_table_reference<T>(self, v: T) -> Selfwhere
T: Into<BigQueryTable>,
Sets the value of table_reference.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::BigQueryTable;
let x = BigQueryKey::new().set_table_reference(BigQueryTable::default()/* use setters */);Sourcepub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryTable>,
pub fn set_or_clear_table_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<BigQueryTable>,
Sets or clears the value of table_reference.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::BigQueryTable;
let x = BigQueryKey::new().set_or_clear_table_reference(Some(BigQueryTable::default()/* use setters */));
let x = BigQueryKey::new().set_or_clear_table_reference(None::<BigQueryTable>);Sourcepub fn set_row_number<T: Into<i64>>(self, v: T) -> Self
pub fn set_row_number<T: Into<i64>>(self, v: T) -> Self