#[non_exhaustive]pub struct BigQueryTableCollection {
pub pattern: Option<Pattern>,
/* private fields */
}Expand description
Specifies a collection of BigQuery tables. Used for Discovery.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pattern: Option<Pattern>Maximum of 100 entries. The first filter containing a pattern that matches a table will be used.
Implementations
Sourceimpl BigQueryTableCollection
impl BigQueryTableCollection
pub fn new() -> Self
Sourcepub fn set_pattern<T: Into<Option<Pattern>>>(self, v: T) -> Self
pub fn set_pattern<T: Into<Option<Pattern>>>(self, v: T) -> Self
Sets the value of pattern.
Note that all the setters affecting pattern are mutually
exclusive.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::BigQueryRegexes;
let x = BigQueryTableCollection::new().set_pattern(Some(
google_cloud_privacy_dlp_v2::model::big_query_table_collection::Pattern::IncludeRegexes(BigQueryRegexes::default().into())));Sourcepub fn include_regexes(&self) -> Option<&Box<BigQueryRegexes>>
pub fn include_regexes(&self) -> Option<&Box<BigQueryRegexes>>
The value of pattern
if it holds a IncludeRegexes, None if the field is not set or
holds a different branch.
Sourcepub fn set_include_regexes<T: Into<Box<BigQueryRegexes>>>(self, v: T) -> Self
pub fn set_include_regexes<T: Into<Box<BigQueryRegexes>>>(self, v: T) -> Self
Sets the value of pattern
to hold a IncludeRegexes.
Note that all the setters affecting pattern are
mutually exclusive.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::BigQueryRegexes;
let x = BigQueryTableCollection::new().set_include_regexes(BigQueryRegexes::default()/* use setters */);
assert!(x.include_regexes().is_some());Trait Implementations
Sourceimpl Clone for BigQueryTableCollection
impl Clone for BigQueryTableCollection
Sourcefn clone(&self) -> BigQueryTableCollection
fn clone(&self) -> BigQueryTableCollection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BigQueryTableCollection
impl Debug for BigQueryTableCollection
Sourceimpl Default for BigQueryTableCollection
impl Default for BigQueryTableCollection
Sourcefn default() -> BigQueryTableCollection
fn default() -> BigQueryTableCollection
Returns the “default value” for a type. Read more
Sourceimpl Message for BigQueryTableCollection
impl Message for BigQueryTableCollection
Sourceimpl PartialEq for BigQueryTableCollection
impl PartialEq for BigQueryTableCollection
impl StructuralPartialEq for BigQueryTableCollection