CreateJobTriggerRequest

Struct CreateJobTriggerRequest 

#[non_exhaustive]
pub struct CreateJobTriggerRequest { pub parent: String, pub job_trigger: Option<JobTrigger>, pub trigger_id: String, pub location_id: String, /* private fields */ }
Request message for CreateJobTrigger.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Parent resource name.

The format of this value varies depending on whether you have specified a processing location:

  • Projects scope, location specified: projects/{project_id}/locations/{location_id}
  • Projects scope, no location specified (defaults to global): projects/{project_id}

The following example parent string specifies a parent project with the identifier example-project, and specifies the europe-west3 location for processing data:

parent=projects/example-project/locations/europe-west3
job_trigger: Option<JobTrigger>

Required. The JobTrigger to create.

trigger_id: String

The trigger id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one.

location_id: String

Deprecated. This field has no effect.

Implementations

Source

impl CreateJobTriggerRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateJobTriggerRequest::new().set_parent("example");
pub fn set_job_trigger<T>(self, v: T) -> Self
where T: Into<JobTrigger>,

Sets the value of job_trigger.

Example
use google_cloud_privacy_dlp_v2::model::JobTrigger;
let x = CreateJobTriggerRequest::new().set_job_trigger(JobTrigger::default()/* use setters */);
pub fn set_or_clear_job_trigger<T>(self, v: Option<T>) -> Self
where T: Into<JobTrigger>,

Sets or clears the value of job_trigger.

Example
use google_cloud_privacy_dlp_v2::model::JobTrigger;
let x = CreateJobTriggerRequest::new().set_or_clear_job_trigger(Some(JobTrigger::default()/* use setters */));
let x = CreateJobTriggerRequest::new().set_or_clear_job_trigger(None::<JobTrigger>);
pub fn set_trigger_id<T: Into<String>>(self, v: T) -> Self

Sets the value of trigger_id.

Example
let x = CreateJobTriggerRequest::new().set_trigger_id("example");
pub fn set_location_id<T: Into<String>>(self, v: T) -> Self

Sets the value of location_id.

Example
let x = CreateJobTriggerRequest::new().set_location_id("example");