#[non_exhaustive]pub struct DatabaseResourceReference {
pub project_id: String,
pub instance: String,
pub database: String,
pub database_resource: String,
/* private fields */
}Expand description
Identifies a single database resource, like a table within a database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringRequired. If within a project-level config, then this must match the config’s project ID.
instance: StringRequired. The instance where this resource is located. For example: Cloud SQL instance ID.
database: StringRequired. Name of a database within the instance.
database_resource: StringRequired. Name of a database resource, for example, a table within the database.
Implementations
Sourceimpl DatabaseResourceReference
impl DatabaseResourceReference
pub fn new() -> Self
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
ⓘ
let x = DatabaseResourceReference::new().set_project_id("example");Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_database<T: Into<String>>(self, v: T) -> Self
pub fn set_database<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_database_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_database_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of database_resource.
Example
ⓘ
let x = DatabaseResourceReference::new().set_database_resource("example");Trait Implementations
Sourceimpl Clone for DatabaseResourceReference
impl Clone for DatabaseResourceReference
Sourcefn clone(&self) -> DatabaseResourceReference
fn clone(&self) -> DatabaseResourceReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatabaseResourceReference
impl Debug for DatabaseResourceReference
Sourceimpl Default for DatabaseResourceReference
impl Default for DatabaseResourceReference
Sourcefn default() -> DatabaseResourceReference
fn default() -> DatabaseResourceReference
Returns the “default value” for a type. Read more
Sourceimpl Message for DatabaseResourceReference
impl Message for DatabaseResourceReference
impl StructuralPartialEq for DatabaseResourceReference