FileStoreCollection

Struct FileStoreCollection 

#[non_exhaustive]
pub struct FileStoreCollection { pub include_tags: Option<TagFilters>, pub pattern: Option<Pattern>, /* private fields */ }
Match file stores (e.g. buckets) using filters.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
include_tags: Option<TagFilters>

Optional. To be included in the collection, a resource must meet all of the following requirements:

  • If tag filters are provided, match all provided tag filters.
  • If one or more patterns are specified, match at least one pattern.

For a resource to match the tag filters, the resource must have all of the provided tags attached. Tags refer to Resource Manager tags bound to the resource or its ancestors. For more information, see Manage schedules.

pattern: Option<Pattern>

The first filter containing a pattern that matches a file store will be used.

Implementations

Source

impl FileStoreCollection

pub fn new() -> Self

pub fn set_include_tags<T>(self, v: T) -> Self
where T: Into<TagFilters>,

Sets the value of include_tags.

Example
use google_cloud_privacy_dlp_v2::model::TagFilters;
let x = FileStoreCollection::new().set_include_tags(TagFilters::default()/* use setters */);
pub fn set_or_clear_include_tags<T>(self, v: Option<T>) -> Self
where T: Into<TagFilters>,

Sets or clears the value of include_tags.

Example
use google_cloud_privacy_dlp_v2::model::TagFilters;
let x = FileStoreCollection::new().set_or_clear_include_tags(Some(TagFilters::default()/* use setters */));
let x = FileStoreCollection::new().set_or_clear_include_tags(None::<TagFilters>);
pub fn set_pattern<T: Into<Option<Pattern>>>(self, v: T) -> Self

Sets the value of pattern.

Note that all the setters affecting pattern are mutually exclusive.

Example
use google_cloud_privacy_dlp_v2::model::FileStoreRegexes;
let x = FileStoreCollection::new().set_pattern(Some(
    google_cloud_privacy_dlp_v2::model::file_store_collection::Pattern::IncludeRegexes(FileStoreRegexes::default().into())));
pub fn include_regexes(&self) -> Option<&Box<FileStoreRegexes>>

The value of pattern if it holds a IncludeRegexes, None if the field is not set or holds a different branch.

pub fn set_include_regexes<T: Into<Box<FileStoreRegexes>>>(self, v: T) -> Self

Sets the value of pattern to hold a IncludeRegexes.

Note that all the setters affecting pattern are mutually exclusive.

Example
use google_cloud_privacy_dlp_v2::model::FileStoreRegexes;
let x = FileStoreCollection::new().set_include_regexes(FileStoreRegexes::default()/* use setters */);
assert!(x.include_regexes().is_some());