FileStoreDataProfile

Struct FileStoreDataProfile 

#[non_exhaustive]
pub struct FileStoreDataProfile {
Show 27 fields pub name: String, pub data_source_type: Option<DataSourceType>, pub project_data_profile: String, pub project_id: String, pub file_store_location: String, pub data_storage_locations: Vec<String>, pub location_type: String, pub file_store_path: String, pub full_resource: String, pub config_snapshot: Option<DataProfileConfigSnapshot>, pub profile_status: Option<ProfileStatus>, pub state: State, pub profile_last_generated: Option<Timestamp>, pub resource_visibility: ResourceVisibility, pub sensitivity_score: Option<SensitivityScore>, pub data_risk_level: Option<DataRiskLevel>, pub create_time: Option<Timestamp>, pub last_modified_time: Option<Timestamp>, pub file_cluster_summaries: Vec<FileClusterSummary>, pub resource_attributes: HashMap<String, Value>, pub resource_labels: HashMap<String, String>, pub file_store_info_type_summaries: Vec<FileStoreInfoTypeSummary>, pub sample_findings_table: Option<BigQueryTable>, pub file_store_is_empty: bool, pub tags: Vec<Tag>, pub related_resources: Vec<RelatedResource>, pub domains: Vec<Domain>, /* private fields */
}
The profile for a file store.

  • Cloud Storage: maps 1:1 with a bucket.
  • Amazon S3: maps 1:1 with a bucket.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The name of the profile.

data_source_type: Option<DataSourceType>

The resource type that was profiled.

project_data_profile: String

The resource name of the project data profile for this file store.

project_id: String

The Google Cloud project ID that owns the resource. For Amazon S3 buckets, this is the AWS Account Id.

file_store_location: Stringdata_storage_locations: Vec<String>

For resources that have multiple storage locations, these are those regions. For Cloud Storage this is the list of regions chosen for dual-region storage. file_store_location will normally be the corresponding multi-region for the list of individual locations. The first region is always picked as the processing and storage location for the data profile.

location_type: String

The location type of the file store (region, dual-region, multi-region, etc). If dual-region, expect data_storage_locations to be populated.

file_store_path: String

The file store path.

  • Cloud Storage: gs://{bucket}
  • Amazon S3: s3://{bucket}
  • Vertex AI dataset: projects/{project_number}/locations/{location}/datasets/{dataset_id}
full_resource: String

The resource name of the resource profiled. https://cloud.google.com/apis/design/resource_names#full_resource_name

Example format of an S3 bucket full resource name: //cloudasset.googleapis.com/organizations/{org_id}/otherCloudConnections/aws/arn:aws:s3:::{bucket_name}

config_snapshot: Option<DataProfileConfigSnapshot>

The snapshot of the configurations used to generate the profile.

profile_status: Option<ProfileStatus>

Success or error status from the most recent profile generation attempt. May be empty if the profile is still being generated.

state: State

State of a profile.

profile_last_generated: Option<Timestamp>

The last time the profile was generated.

resource_visibility: ResourceVisibility

How broadly a resource has been shared.

sensitivity_score: Option<SensitivityScore>

The sensitivity score of this resource.

data_risk_level: Option<DataRiskLevel>

The data risk level of this resource.

create_time: Option<Timestamp>

The time the file store was first created.

last_modified_time: Option<Timestamp>

The time the file store was last modified.

file_cluster_summaries: Vec<FileClusterSummary>

FileClusterSummary per each cluster.

resource_attributes: HashMap<String, Value>

Attributes of the resource being profiled. Currently used attributes:

  • customer_managed_encryption: boolean
    • true: the resource is encrypted with a customer-managed key.
    • false: the resource is encrypted with a provider-managed key.
resource_labels: HashMap<String, String>

The labels applied to the resource at the time the profile was generated.

file_store_info_type_summaries: Vec<FileStoreInfoTypeSummary>

InfoTypes detected in this file store.

sample_findings_table: Option<BigQueryTable>

The BigQuery table to which the sample findings are written.

file_store_is_empty: bool

The file store does not have any files. If the profiling operation failed, this is false.

tags: Vec<Tag>

The tags attached to the resource, including any tags attached during profiling.

related_resources: Vec<RelatedResource>

Resources related to this profile.

domains: Vec<Domain>

Domains associated with the profile.

Implementations

Source

impl FileStoreDataProfile

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = FileStoreDataProfile::new().set_name("example");
pub fn set_data_source_type<T>(self, v: T) -> Self
where T: Into<DataSourceType>,

Sets the value of data_source_type.

Example
use google_cloud_privacy_dlp_v2::model::DataSourceType;
let x = FileStoreDataProfile::new().set_data_source_type(DataSourceType::default()/* use setters */);
pub fn set_or_clear_data_source_type<T>(self, v: Option<T>) -> Self
where T: Into<DataSourceType>,

Sets or clears the value of data_source_type.

Example
use google_cloud_privacy_dlp_v2::model::DataSourceType;
let x = FileStoreDataProfile::new().set_or_clear_data_source_type(Some(DataSourceType::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_data_source_type(None::<DataSourceType>);
pub fn set_project_data_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of project_data_profile.

Example
let x = FileStoreDataProfile::new().set_project_data_profile("example");
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of project_id.

Example
let x = FileStoreDataProfile::new().set_project_id("example");
pub fn set_file_store_location<T: Into<String>>(self, v: T) -> Self

Sets the value of file_store_location.

Example
let x = FileStoreDataProfile::new().set_file_store_location("example");
pub fn set_data_storage_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of data_storage_locations.

Example
let x = FileStoreDataProfile::new().set_data_storage_locations(["a", "b", "c"]);
pub fn set_location_type<T: Into<String>>(self, v: T) -> Self

Sets the value of location_type.

Example
let x = FileStoreDataProfile::new().set_location_type("example");
pub fn set_file_store_path<T: Into<String>>(self, v: T) -> Self

Sets the value of file_store_path.

Example
let x = FileStoreDataProfile::new().set_file_store_path("example");
pub fn set_full_resource<T: Into<String>>(self, v: T) -> Self

Sets the value of full_resource.

Example
let x = FileStoreDataProfile::new().set_full_resource("example");
pub fn set_config_snapshot<T>(self, v: T) -> Self

Sets the value of config_snapshot.

Example
use google_cloud_privacy_dlp_v2::model::DataProfileConfigSnapshot;
let x = FileStoreDataProfile::new().set_config_snapshot(DataProfileConfigSnapshot::default()/* use setters */);
pub fn set_or_clear_config_snapshot<T>(self, v: Option<T>) -> Self

Sets or clears the value of config_snapshot.

Example
use google_cloud_privacy_dlp_v2::model::DataProfileConfigSnapshot;
let x = FileStoreDataProfile::new().set_or_clear_config_snapshot(Some(DataProfileConfigSnapshot::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_config_snapshot(None::<DataProfileConfigSnapshot>);
pub fn set_profile_status<T>(self, v: T) -> Self
where T: Into<ProfileStatus>,

Sets the value of profile_status.

Example
use google_cloud_privacy_dlp_v2::model::ProfileStatus;
let x = FileStoreDataProfile::new().set_profile_status(ProfileStatus::default()/* use setters */);
pub fn set_or_clear_profile_status<T>(self, v: Option<T>) -> Self
where T: Into<ProfileStatus>,

Sets or clears the value of profile_status.

Example
use google_cloud_privacy_dlp_v2::model::ProfileStatus;
let x = FileStoreDataProfile::new().set_or_clear_profile_status(Some(ProfileStatus::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_profile_status(None::<ProfileStatus>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_privacy_dlp_v2::model::file_store_data_profile::State;
let x0 = FileStoreDataProfile::new().set_state(State::Running);
let x1 = FileStoreDataProfile::new().set_state(State::Done);
pub fn set_profile_last_generated<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of profile_last_generated.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_profile_last_generated(Timestamp::default()/* use setters */);
pub fn set_or_clear_profile_last_generated<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of profile_last_generated.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_or_clear_profile_last_generated(Some(Timestamp::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_profile_last_generated(None::<Timestamp>);
pub fn set_resource_visibility<T: Into<ResourceVisibility>>(self, v: T) -> Self

Sets the value of resource_visibility.

Example
use google_cloud_privacy_dlp_v2::model::ResourceVisibility;
let x0 = FileStoreDataProfile::new().set_resource_visibility(ResourceVisibility::Public);
let x1 = FileStoreDataProfile::new().set_resource_visibility(ResourceVisibility::Inconclusive);
let x2 = FileStoreDataProfile::new().set_resource_visibility(ResourceVisibility::Restricted);
pub fn set_sensitivity_score<T>(self, v: T) -> Self

Sets the value of sensitivity_score.

Example
use google_cloud_privacy_dlp_v2::model::SensitivityScore;
let x = FileStoreDataProfile::new().set_sensitivity_score(SensitivityScore::default()/* use setters */);
pub fn set_or_clear_sensitivity_score<T>(self, v: Option<T>) -> Self

Sets or clears the value of sensitivity_score.

Example
use google_cloud_privacy_dlp_v2::model::SensitivityScore;
let x = FileStoreDataProfile::new().set_or_clear_sensitivity_score(Some(SensitivityScore::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_sensitivity_score(None::<SensitivityScore>);
pub fn set_data_risk_level<T>(self, v: T) -> Self
where T: Into<DataRiskLevel>,

Sets the value of data_risk_level.

Example
use google_cloud_privacy_dlp_v2::model::DataRiskLevel;
let x = FileStoreDataProfile::new().set_data_risk_level(DataRiskLevel::default()/* use setters */);
pub fn set_or_clear_data_risk_level<T>(self, v: Option<T>) -> Self
where T: Into<DataRiskLevel>,

Sets or clears the value of data_risk_level.

Example
use google_cloud_privacy_dlp_v2::model::DataRiskLevel;
let x = FileStoreDataProfile::new().set_or_clear_data_risk_level(Some(DataRiskLevel::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_data_risk_level(None::<DataRiskLevel>);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_last_modified_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of last_modified_time.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_last_modified_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_last_modified_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of last_modified_time.

Example
use wkt::Timestamp;
let x = FileStoreDataProfile::new().set_or_clear_last_modified_time(Some(Timestamp::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_last_modified_time(None::<Timestamp>);
pub fn set_file_cluster_summaries<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<FileClusterSummary>,

Sets the value of file_cluster_summaries.

Example
use google_cloud_privacy_dlp_v2::model::FileClusterSummary;
let x = FileStoreDataProfile::new()
    .set_file_cluster_summaries([
        FileClusterSummary::default()/* use setters */,
        FileClusterSummary::default()/* use (different) setters */,
    ]);
pub fn set_resource_attributes<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<Value>,

Sets the value of resource_attributes.

Example
use google_cloud_privacy_dlp_v2::model::Value;
let x = FileStoreDataProfile::new().set_resource_attributes([
    ("key0", Value::default()/* use setters */),
    ("key1", Value::default()/* use (different) setters */),
]);
pub fn set_resource_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of resource_labels.

Example
let x = FileStoreDataProfile::new().set_resource_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_file_store_info_type_summaries<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<FileStoreInfoTypeSummary>,

Sets the value of file_store_info_type_summaries.

Example
use google_cloud_privacy_dlp_v2::model::FileStoreInfoTypeSummary;
let x = FileStoreDataProfile::new()
    .set_file_store_info_type_summaries([
        FileStoreInfoTypeSummary::default()/* use setters */,
        FileStoreInfoTypeSummary::default()/* use (different) setters */,
    ]);
pub fn set_sample_findings_table<T>(self, v: T) -> Self
where T: Into<BigQueryTable>,

Sets the value of sample_findings_table.

Example
use google_cloud_privacy_dlp_v2::model::BigQueryTable;
let x = FileStoreDataProfile::new().set_sample_findings_table(BigQueryTable::default()/* use setters */);
pub fn set_or_clear_sample_findings_table<T>(self, v: Option<T>) -> Self
where T: Into<BigQueryTable>,

Sets or clears the value of sample_findings_table.

Example
use google_cloud_privacy_dlp_v2::model::BigQueryTable;
let x = FileStoreDataProfile::new().set_or_clear_sample_findings_table(Some(BigQueryTable::default()/* use setters */));
let x = FileStoreDataProfile::new().set_or_clear_sample_findings_table(None::<BigQueryTable>);
pub fn set_file_store_is_empty<T: Into<bool>>(self, v: T) -> Self

Sets the value of file_store_is_empty.

Example
let x = FileStoreDataProfile::new().set_file_store_is_empty(true);
pub fn set_tags<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Tag>,

Sets the value of tags.

Example
use google_cloud_privacy_dlp_v2::model::Tag;
let x = FileStoreDataProfile::new()
    .set_tags([
        Tag::default()/* use setters */,
        Tag::default()/* use (different) setters */,
    ]);

Sets the value of related_resources.

Example
use google_cloud_privacy_dlp_v2::model::RelatedResource;
let x = FileStoreDataProfile::new()
    .set_related_resources([
        RelatedResource::default()/* use setters */,
        RelatedResource::default()/* use (different) setters */,
    ]);
pub fn set_domains<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Domain>,

Sets the value of domains.

Example
use google_cloud_privacy_dlp_v2::model::Domain;
let x = FileStoreDataProfile::new()
    .set_domains([
        Domain::default()/* use setters */,
        Domain::default()/* use (different) setters */,
    ]);