#[non_exhaustive]pub struct FileStoreRegex {
pub resource_regex: Option<ResourceRegex>,
/* private fields */
}Expand description
A pattern to match against one or more file stores.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_regex: Option<ResourceRegex>The type of resource regex to use.
Implementations
Sourceimpl FileStoreRegex
impl FileStoreRegex
pub fn new() -> Self
Sourcepub fn set_resource_regex<T: Into<Option<ResourceRegex>>>(self, v: T) -> Self
pub fn set_resource_regex<T: Into<Option<ResourceRegex>>>(self, v: T) -> Self
Sets the value of resource_regex.
Note that all the setters affecting resource_regex are mutually
exclusive.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::CloudStorageRegex;
let x = FileStoreRegex::new().set_resource_regex(Some(
google_cloud_privacy_dlp_v2::model::file_store_regex::ResourceRegex::CloudStorageRegex(CloudStorageRegex::default().into())));Sourcepub fn cloud_storage_regex(&self) -> Option<&Box<CloudStorageRegex>>
pub fn cloud_storage_regex(&self) -> Option<&Box<CloudStorageRegex>>
The value of resource_regex
if it holds a CloudStorageRegex, None if the field is not set or
holds a different branch.
Sourcepub fn set_cloud_storage_regex<T: Into<Box<CloudStorageRegex>>>(
self,
v: T,
) -> Self
pub fn set_cloud_storage_regex<T: Into<Box<CloudStorageRegex>>>( self, v: T, ) -> Self
Sets the value of resource_regex
to hold a CloudStorageRegex.
Note that all the setters affecting resource_regex are
mutually exclusive.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::CloudStorageRegex;
let x = FileStoreRegex::new().set_cloud_storage_regex(CloudStorageRegex::default()/* use setters */);
assert!(x.cloud_storage_regex().is_some());Trait Implementations
Sourceimpl Clone for FileStoreRegex
impl Clone for FileStoreRegex
Sourcefn clone(&self) -> FileStoreRegex
fn clone(&self) -> FileStoreRegex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileStoreRegex
impl Debug for FileStoreRegex
Sourceimpl Default for FileStoreRegex
impl Default for FileStoreRegex
Sourcefn default() -> FileStoreRegex
fn default() -> FileStoreRegex
Returns the “default value” for a type. Read more
Sourceimpl Message for FileStoreRegex
impl Message for FileStoreRegex
Sourceimpl PartialEq for FileStoreRegex
impl PartialEq for FileStoreRegex
impl StructuralPartialEq for FileStoreRegex