ListFileStoreDataProfilesRequest

Struct ListFileStoreDataProfilesRequest 

#[non_exhaustive]
pub struct ListFileStoreDataProfilesRequest { pub parent: String, pub page_token: String, pub page_size: i32, pub order_by: String, pub filter: String, /* private fields */ }
Request to list the file store profiles generated for a given organization or project.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Resource name of the organization or project, for example organizations/433245324/locations/europe or projects/project-id/locations/asia.

page_token: String

Optional. Page token to continue retrieval.

page_size: i32

Optional. Size of the page. This value can be limited by the server. If zero, server returns a page of max size 100.

order_by: String

Optional. Comma-separated list of fields to order by, followed by asc or desc postfix. This list is case insensitive. The default sorting order is ascending. Redundant space characters are insignificant. Only one order field at a time is allowed.

Examples:

  • project_id asc
  • name
  • sensitivity_level desc

Supported fields are:

  • project_id: The Google Cloud project ID.
  • sensitivity_level: How sensitive the data in a table is, at most.
  • data_risk_level: How much risk is associated with this data.
  • profile_last_generated: When the profile was last updated in epoch seconds.
  • last_modified: The last time the resource was modified.
  • resource_visibility: Visibility restriction for this resource.
  • name: The name of the profile.
  • create_time: The time the file store was first created.
filter: String

Optional. Allows filtering.

Supported syntax:

  • Filter expressions are made up of one or more restrictions.

  • Restrictions can be combined by AND or OR logical operators. A sequence of restrictions implicitly uses AND.

  • A restriction has the form of {field} {operator} {value}.

  • Supported fields:

    • project_id: The Google Cloud project ID
    • account_id: The AWS account ID
    • file_store_path: The path like “gs://bucket”
    • data_source_type: The profile’s data source type, like “google/storage/bucket”
    • data_storage_location: The location where the file store’s data is stored, like “us-central1”
    • sensitivity_level: HIGH|MODERATE|LOW
    • data_risk_level: HIGH|MODERATE|LOW
    • resource_visibility: PUBLIC|RESTRICTED
    • status_code: an RPC status code as defined in https://github.com/googleapis/googleapis/blob/master/google/rpc/code.proto
    • profile_last_generated: Date and time the profile was last generated
  • The operator must be = or !=. The profile_last_generated filter also supports < and >.

The syntax is based on https://google.aip.dev/160.

Examples:

  • project_id = 12345 AND status_code = 1
  • project_id = 12345 AND sensitivity_level = HIGH
  • project_id = 12345 AND resource_visibility = PUBLIC
  • file_store_path = "gs://mybucket"
  • profile_last_generated < "2025-01-01T00:00:00.000Z"

The length of this field should be no more than 500 characters.

Implementations

Source

impl ListFileStoreDataProfilesRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListFileStoreDataProfilesRequest::new().set_parent("example");
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListFileStoreDataProfilesRequest::new().set_page_token("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListFileStoreDataProfilesRequest::new().set_page_size(42);
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
let x = ListFileStoreDataProfilesRequest::new().set_order_by("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListFileStoreDataProfilesRequest::new().set_filter("example");