#[non_exhaustive]pub struct ListFileStoreDataProfilesResponse {
pub file_store_data_profiles: Vec<FileStoreDataProfile>,
pub next_page_token: String,
/* private fields */
}Expand description
List of file store data profiles generated for a given organization or project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_store_data_profiles: Vec<FileStoreDataProfile>List of data profiles.
next_page_token: StringThe next page token.
Implementations
Sourceimpl ListFileStoreDataProfilesResponse
impl ListFileStoreDataProfilesResponse
pub fn new() -> Self
Sourcepub fn set_file_store_data_profiles<T, V>(self, v: T) -> Self
pub fn set_file_store_data_profiles<T, V>(self, v: T) -> Self
Sets the value of file_store_data_profiles.
Example
ⓘ
use google_cloud_privacy_dlp_v2::model::FileStoreDataProfile;
let x = ListFileStoreDataProfilesResponse::new()
.set_file_store_data_profiles([
FileStoreDataProfile::default()/* use setters */,
FileStoreDataProfile::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListFileStoreDataProfilesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListFileStoreDataProfilesResponse
impl Clone for ListFileStoreDataProfilesResponse
Sourcefn clone(&self) -> ListFileStoreDataProfilesResponse
fn clone(&self) -> ListFileStoreDataProfilesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListFileStoreDataProfilesResponse
impl Default for ListFileStoreDataProfilesResponse
Sourcefn default() -> ListFileStoreDataProfilesResponse
fn default() -> ListFileStoreDataProfilesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListFileStoreDataProfilesResponse
impl PartialEq for ListFileStoreDataProfilesResponse
Sourcefn eq(&self, other: &ListFileStoreDataProfilesResponse) -> bool
fn eq(&self, other: &ListFileStoreDataProfilesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListFileStoreDataProfilesResponse