#[non_exhaustive]pub struct CreateJobTriggerRequest {
pub parent: String,
pub job_trigger: Option<JobTrigger>,
pub trigger_id: String,
pub location_id: String,
/* private fields */
}Expand description
Request message for CreateJobTrigger.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent resource name.
The format of this value varies depending on whether you have specified a processing location:
- Projects scope, location specified:
projects/{project_id}/locations/{location_id} - Projects scope, no location specified (defaults to global):
projects/{project_id}
The following example parent string specifies a parent project with the
identifier example-project, and specifies the europe-west3 location
for processing data:
parent=projects/example-project/locations/europe-west3job_trigger: Option<JobTrigger>Required. The JobTrigger to create.
trigger_id: StringThe trigger id can contain uppercase and lowercase letters,
numbers, and hyphens; that is, it must match the regular
expression: [a-zA-Z\d-_]+. The maximum length is 100
characters. Can be empty to allow the system to generate one.
location_id: StringDeprecated. This field has no effect.
Implementations
Sourceimpl CreateJobTriggerRequest
impl CreateJobTriggerRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_trigger<T>(self, v: T) -> Selfwhere
T: Into<JobTrigger>,
pub fn set_job_trigger<T>(self, v: T) -> Selfwhere
T: Into<JobTrigger>,
Sets the value of job_trigger.
Example
use google_cloud_privacy_dlp_v2::model::JobTrigger;
let x = CreateJobTriggerRequest::new().set_job_trigger(JobTrigger::default()/* use setters */);Sourcepub fn set_or_clear_job_trigger<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobTrigger>,
pub fn set_or_clear_job_trigger<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobTrigger>,
Sets or clears the value of job_trigger.
Example
use google_cloud_privacy_dlp_v2::model::JobTrigger;
let x = CreateJobTriggerRequest::new().set_or_clear_job_trigger(Some(JobTrigger::default()/* use setters */));
let x = CreateJobTriggerRequest::new().set_or_clear_job_trigger(None::<JobTrigger>);Sourcepub fn set_trigger_id<T: Into<String>>(self, v: T) -> Self
pub fn set_trigger_id<T: Into<String>>(self, v: T) -> Self
Sets the value of trigger_id.
Example
let x = CreateJobTriggerRequest::new().set_trigger_id("example");Sourcepub fn set_location_id<T: Into<String>>(self, v: T) -> Self
pub fn set_location_id<T: Into<String>>(self, v: T) -> Self
Sets the value of location_id.
Example
let x = CreateJobTriggerRequest::new().set_location_id("example");Trait Implementations
Sourceimpl Clone for CreateJobTriggerRequest
impl Clone for CreateJobTriggerRequest
Sourcefn clone(&self) -> CreateJobTriggerRequest
fn clone(&self) -> CreateJobTriggerRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more