#[non_exhaustive]pub struct ListFileStoreDataProfilesRequest {
pub parent: String,
pub page_token: String,
pub page_size: i32,
pub order_by: String,
pub filter: String,
/* private fields */
}Expand description
Request to list the file store profiles generated for a given organization or project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Resource name of the organization or project, for
example organizations/433245324/locations/europe or
projects/project-id/locations/asia.
page_token: StringOptional. Page token to continue retrieval.
page_size: i32Optional. Size of the page. This value can be limited by the server. If zero, server returns a page of max size 100.
order_by: StringOptional. Comma-separated list of fields to order by, followed by asc or
desc postfix. This list is case insensitive. The default sorting order is
ascending. Redundant space characters are insignificant. Only one order
field at a time is allowed.
Examples:
project_id ascnamesensitivity_level desc
Supported fields are:
project_id: The Google Cloud project ID.sensitivity_level: How sensitive the data in a table is, at most.data_risk_level: How much risk is associated with this data.profile_last_generated: When the profile was last updated in epoch seconds.last_modified: The last time the resource was modified.resource_visibility: Visibility restriction for this resource.name: The name of the profile.create_time: The time the file store was first created.
filter: StringOptional. Allows filtering.
Supported syntax:
-
Filter expressions are made up of one or more restrictions.
-
Restrictions can be combined by
ANDorORlogical operators. A sequence of restrictions implicitly usesAND. -
A restriction has the form of
{field} {operator} {value}. -
Supported fields:
project_id: The Google Cloud project IDaccount_id: The AWS account IDfile_store_path: The path like “gs://bucket”data_source_type: The profile’s data source type, like “google/storage/bucket”data_storage_location: The location where the file store’s data is stored, like “us-central1”sensitivity_level: HIGH|MODERATE|LOWdata_risk_level: HIGH|MODERATE|LOWresource_visibility: PUBLIC|RESTRICTEDstatus_code: an RPC status code as defined in https://github.com/googleapis/googleapis/blob/master/google/rpc/code.protoprofile_last_generated: Date and time the profile was last generated
-
The operator must be
=or!=. Theprofile_last_generatedfilter also supports<and>.
The syntax is based on https://google.aip.dev/160.
Examples:
project_id = 12345 AND status_code = 1project_id = 12345 AND sensitivity_level = HIGHproject_id = 12345 AND resource_visibility = PUBLICfile_store_path = "gs://mybucket"profile_last_generated < "2025-01-01T00:00:00.000Z"
The length of this field should be no more than 500 characters.
Implementations
Sourceimpl ListFileStoreDataProfilesRequest
impl ListFileStoreDataProfilesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListFileStoreDataProfilesRequest::new().set_page_token("example");Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self